@@ -1,14 +1,13 @@
 package Search::Elasticsearch::Async;
 
-use Search::Elasticsearch 1.19;
-
+use Search::Elasticsearch 1.20;
 use Promises 0.93 ();
-use Moo 1.003;
-extends 'Search::Elasticsearch';
+use parent 'Search::Elasticsearch';
+
 use Search::Elasticsearch::Util qw(parse_params);
 use namespace::clean;
 
-our $VERSION = '1.19';
+our $VERSION = '1.20';
 
 #===================================
 sub new {
@@ -41,7 +40,7 @@ Search::Elasticsearch::Async - Async API for Elasticsearch using Promises
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 SYNOPSIS
 
@@ -119,7 +118,7 @@ L<Search::Elasticsearch::Async> is the official B<asynchronous> Perl client for
 Elasticsearch, supported by L<elasticsearch.com|http://www.elasticsearch.com>.
 Elasticsearch itself is a flexible and powerful open source, distributed real-time
 search and analytics engine for the cloud.  You can read more about it
-on L<elasticsearch.org|http://www.elasticsearch.org>.
+on L<elastic.co|http://www.elastic.co>.
 
 This module uses L<Promises> to provide a sane async interface, making your
 async code look more like synchronous code.  It can be used with
@@ -280,7 +279,7 @@ is repeated until the application is interrupted with C<Ctrl-C>.:
 
 =head1 CREATING A NEW INSTANCE
 
-The L</new()> method returns a new L<client|Search::Elasticsearch::Client::Direct>
+The L</new()> method returns a new L<client|Search::Elasticsearch::Client::1_0::Direct>
 which can be used to run requests against the Elasticsearch cluster.
 
     use Search::Elasticsearch::Async;
@@ -400,7 +399,7 @@ Other arguments are explained in the respective L<module docs|/MODULES>.
 =head1 RUNNING REQUESTS
 
 When you create a new instance of Search::Elasticsearch::Async, it returns a
-L<client|Search::Elasticsearch::Client::Direct> object, which can be used for
+L<client|Search::Elasticsearch::Client::1_0::Direct> object, which can be used for
 running requests.
 
     use Search::Elasticsearch::Async;
@@ -424,7 +423,7 @@ running requests.
         );
     });
 
-See L<Search::Elasticsearch::Client::Direct> for more details about the requests
+See L<Search::Elasticsearch::Client::1_0::Direct> for more details about the requests
 that can be run.
 
 =head1 MODULES
@@ -455,11 +454,21 @@ The class to use for the client functionality, which provides
 methods that can be called to execute requests, such as
 C<search()>, C<index()> or C<delete()>. The client parses the user's
 requests and passes them to the L</transport> class to be executed.
+
+The default version of the client is C<1_0::Direct>, which can
+be explicitly specified as follows:
+
+    $e = Search::Elasticsearch::Async->new(
+        client => '1_0::Direct'
+    );
+
 See :
 
 =over
 
-=item * L<Search::Elasticsearch::Client::Direct> (default, for 1.0 branch)
+=item * L<Search::Elasticsearch::Client::1_0::Direct> (default, for 1.0 branch)
+
+=item * L<Search::Elasticsearch::Client::2_0::Direct> (for 2.0 branch)
 
 =item * L<Search::Elasticsearch::Client::0_90::Direct> (for 0.90 branch)
 
@@ -596,7 +605,7 @@ C<irc.freenode.net>.
 
 =item * Mailing list
 
-The main L<Elasticsearch mailing list|http://www.elasticsearch.org/community/forum/>.
+The main L<Elasticsearch mailing list|http://www.elastic.co/community>.
 
 =back
 
