@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Async::Bulk;
-$Search::Elasticsearch::Async::Bulk::VERSION = '1.19';
+$Search::Elasticsearch::Async::Bulk::VERSION = '1.20';
 use Moo;
 with 'Search::Elasticsearch::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Async';
@@ -94,8 +94,8 @@ sub flush {
         = $self->es->bulk( %{ $self->_bulk_args }, body => \@items )->catch(
         sub {
             my $error = shift;
-            if ( $error->isa('Cxn') ) {
-                push @{ $self->buffer }, @items;
+            if ( $error->is( 'Cxn', 'NoNodes' ) ) {
+                push @{ $self->_buffer }, @items;
                 $self->_buffer_size( $self->_buffer_size + $size );
                 $self->_buffer_count( $self->_buffer_count + $count );
             }
@@ -206,7 +206,7 @@ Search::Elasticsearch::Async::Bulk - A helper module for the Bulk API and for re
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 SYNOPSIS
 
@@ -249,7 +249,7 @@ version 1.19
 
 =head1 DESCRIPTION
 
-This module provides an async wrapper for the L<Search::Elasticsearch::Client::Direct/bulk()>
+This module provides an async wrapper for the L<Search::Elasticsearch::Client::1_0::Direct/bulk()>
 method which makes it easier to run multiple create, index, update or delete
 actions in a single request. It also provides a simple interface
 for L<reindexing documents|/REINDEXING DOCUMENTS>.
@@ -292,7 +292,7 @@ calls L</new()> with the specified parameters and returns a new C<$bulk> object.
 The C<index> and C<type> parameters provide default values for
 C<index> and C<type>, which can be overridden in each action.
 You can also pass any other values which are accepted
-by the L<bulk()|Search::Elasticsearch::Client::Direct/bulk()> method.
+by the L<bulk()|Search::Elasticsearch::Client::1_0::Direct/bulk()> method.
 
 See L</flush()> for more information about the other parameters.
 
@@ -303,7 +303,7 @@ See L</flush()> for more information about the other parameters.
     $promise = $bulk->flush;
 
 The C<flush()> method sends all buffered actions to Elasticsearch using
-a L<bulk()|Search::Elasticsearch::Client::Direct/bulk()> request and returns
+a L<bulk()|Search::Elasticsearch::Client::1_0::Direct/bulk()> request and returns
 a L<Promise>, which is rejected if the bulk request fails or if any of
 the C<on_success>, C<on_error> or C<on_conflict> callbacks throws an
 exception, otherwise it is resolved with the items that have been flushed.
@@ -503,7 +503,7 @@ they must be specified either in L</new()> or in every action.
     );
 
 The C<create()> helper method allows you to add multiple C<create> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::Direct/create()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/create()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -529,7 +529,7 @@ you can just pass the individual document bodies.
     );
 
 The C<index()> helper method allows you to add multiple C<index> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::Direct/index()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/index()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -542,7 +542,7 @@ parameter, instead of as C<body>.
     );
 
 The C<delete()> helper method allows you to add multiple C<delete> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::Direct/delete()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/delete()>.
 
 =head2 C<delete_ids()>
 
@@ -569,7 +569,7 @@ In this case, all you have to do is to pass in a list of IDs.
     );
 
 The C<update()> helper method allows you to add multiple C<update> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::Direct/update()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/update()>.
 An update can either use a I<partial doc> which gets merged with an existing
 doc (example 1 above), or can use a C<script> to update an existing doc
 (example 2 above).
