@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Transport::Async;
-$Search::Elasticsearch::Transport::Async::VERSION = '1.19';
+$Search::Elasticsearch::Transport::Async::VERSION = '1.20';
 use Moo;
 with 'Search::Elasticsearch::Role::Is_Async',
     'Search::Elasticsearch::Role::Transport';
@@ -60,7 +60,6 @@ sub perform_request {
             if ($cxn) {
                 $logger->trace_request( $cxn, $params );
                 $logger->trace_error( $cxn, $error );
-                delete $error->{vars}{body};
             }
             $error->is('NoNodes')
                 ? $logger->critical($error)
@@ -87,7 +86,7 @@ Search::Elasticsearch::Transport::Async - Provides async interface between the c
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 DESCRIPTION
 
@@ -106,7 +105,7 @@ L<Search::Elasticsearch::Role::Is_Async>.
         send_get_body_as => 'POST'
     );
 
-Certain endpoints like L<Search::Elasticsearch::Client::Direct/search()>
+Certain endpoints like L<Search::Elasticsearch::Client::1_0::Direct/search()>
 default to using a C<GET> method, even when they include a request body.
 Some proxy servers do not support C<GET> requests with a body.  To work
 around this, the C<send_get_body_as>  parameter accepts the following:
